@@ -247,7 +247,7 @@ pub fn superkey(palette: ColoredElements, separator: &str) -> LinePart {
 }
 
 pub fn ctrl_keys(help: &ModeInfo, max_len: usize, separator: &str) -> LinePart {
-    let colored_elements = color_elements(help.palette);
+    let colored_elements = color_elements(help.style.colors);
     match &help.mode {
         InputMode::Locked => key_indicators(
             max_len,
