@@ -81,8 +81,8 @@ impl FakeStdoutWriter {
     }
 }
 impl io::Write for FakeStdoutWriter {
-    fn write(&mut self, mut buf: &[u8]) -> Result<usize, io::Error> {
-        self.buffer.lock().unwrap().extend_from_slice(&mut buf);
+    fn write(&mut self, buf: &[u8]) -> Result<usize, io::Error> {
+        self.buffer.lock().unwrap().extend_from_slice(buf);
         Ok(buf.len())
     }
     fn flush(&mut self) -> Result<(), io::Error> {
@@ -151,7 +151,7 @@ impl ClientOsApi for FakeClientOsApi {
             command_is_executing.unblock_input_thread();
         }
     }
-    fn recv_from_server(&self) -> (ServerToClientMsg, ErrorContext) {
+    fn recv_from_server(&self) -> Option<(ServerToClientMsg, ErrorContext)> {
         unimplemented!()
     }
     fn handle_signals(&self, _sigwinch_cb: Box<dyn Fn()>, _quit_cb: Box<dyn Fn()>) {
@@ -188,7 +188,7 @@ fn extract_pixel_events_sent_to_server(
     let events_sent_to_server = events_sent_to_server.lock().unwrap();
     events_sent_to_server.iter().fold(vec![], |mut acc, event| {
         if let ClientToServerMsg::TerminalPixelDimensions(pixel_dimensions) = event {
-            acc.push(pixel_dimensions.clone());
+            acc.push(*pixel_dimensions);
         }
         acc
     })
@@ -319,8 +319,7 @@ pub fn pixel_info_queried_from_terminal_emulator() {
 
     let events_sent_to_server = Arc::new(Mutex::new(vec![]));
     let command_is_executing = CommandIsExecuting::new();
-    let client_os_api =
-        FakeClientOsApi::new(events_sent_to_server.clone(), command_is_executing.clone());
+    let client_os_api = FakeClientOsApi::new(events_sent_to_server, command_is_executing.clone());
     let config = Config::from_default_assets().unwrap();
     let options = Options::default();
 
@@ -353,7 +352,9 @@ pub fn pixel_info_queried_from_terminal_emulator() {
     let extracted_stdout_buffer = client_os_api_clone.stdout_buffer();
     assert_eq!(
         String::from_utf8(extracted_stdout_buffer),
-        Ok(String::from("\u{1b}[14t\u{1b}[16t")),
+        Ok(String::from(
+            "\u{1b}[14t\u{1b}[16t\u{1b}]11;?\u{1b}\\\u{1b}]10;?\u{1b}\\"
+        )),
     );
 }
 
@@ -465,8 +466,7 @@ pub fn pixel_info_sent_to_server() {
         receive_input_instructions,
     );
     let actions_sent_to_server = extract_actions_sent_to_server(events_sent_to_server.clone());
-    let pixel_events_sent_to_server =
-        extract_pixel_events_sent_to_server(events_sent_to_server.clone());
+    let pixel_events_sent_to_server = extract_pixel_events_sent_to_server(events_sent_to_server);
     assert_eq!(actions_sent_to_server, vec![Action::Quit]);
     assert_eq!(
         pixel_events_sent_to_server,
@@ -588,8 +588,7 @@ pub fn corrupted_pixel_info_sent_as_key_events() {
         receive_input_instructions,
     );
     let actions_sent_to_server = extract_actions_sent_to_server(events_sent_to_server.clone());
-    let pixel_events_sent_to_server =
-        extract_pixel_events_sent_to_server(events_sent_to_server.clone());
+    let pixel_events_sent_to_server = extract_pixel_events_sent_to_server(events_sent_to_server);
     assert_eq!(
         actions_sent_to_server,
         vec![
@@ -716,8 +715,7 @@ pub fn esc_in_the_middle_of_pixelinfo_breaks_out_of_it() {
         receive_input_instructions,
     );
     let actions_sent_to_server = extract_actions_sent_to_server(events_sent_to_server.clone());
-    let pixel_events_sent_to_server =
-        extract_pixel_events_sent_to_server(events_sent_to_server.clone());
+    let pixel_events_sent_to_server = extract_pixel_events_sent_to_server(events_sent_to_server);
     assert_eq!(
         actions_sent_to_server,
         vec![
