@@ -230,7 +230,7 @@ pub fn start_server(mut os_input: Box<dyn ServerOsApi>, socket_path: PathBuf) {
             move || {
                 drop(std::fs::remove_file(&socket_path));
                 let listener = LocalSocketListener::bind(&*socket_path).unwrap();
-                set_permissions(&socket_path).unwrap();
+                set_permissions(&socket_path, 0o700).unwrap();
                 for stream in listener.incoming() {
                     match stream {
                         Ok(stream) => {
