@@ -15,8 +15,10 @@ pub use anyhow;
 pub use async_std;
 pub use clap;
 pub use interprocess;
+pub use lazy_static;
 pub use libc;
 pub use nix;
+pub use regex;
 pub use serde;
 pub use serde_yaml;
 pub use signal_hook;
